same_stroke = [
    "聿律津",
    "虎虚虑虔",
    "类粪",
    "喂偎",
    "馈溃匮聩篑愦愦",
    "复腹覆馥蝮履",
    "人入",
    "监滥槛",
    "共洪供拱哄",
    "内柄纳呐",
    "乏泛眨",
    "输暖载栽",
    "掉卓桌",
    "参掺惨渗",
    "向响晌",
    "月朋膊脯育肓脊背",
    "将奖浆蒋",
    "部剖陪培倍焙赔",
    "台抬胎苔怡治冶始",
    "郎朗",
    "平评苹萍",
    "采彩睬踩菜",
    "锋蜂峰缝",
    "秋愁揪鳅",
    "曼漫慢蔓谩幔馒",
    "反版板饭返",
    "列例烈裂冽咧",
    "婉晚豌惋",
    "碍得",
    "泣拉",
    "椽喙蠡掾缘",
    "因困",
    "货度",
    "蓦募",
    "宾滨",
    "买卖续读",
    "耽眈忱枕",
    "扁篇骗偏遍编",
    "交狡校郊胶效跤饺绞咬",
    "丑扭钮纽",
    "蹇搴褰骞",
    "撩嘹潦燎镣",
    "灾烧煤炎焚",
    "洎汨汩",
    "谡稷",
    "免兔挽勉冕晚娩搀馋逸",
    "赞攒",
    "乔骄桥轿娇侨矫",
    "挪娜那哪",
    "请清情晴精睛慎",
    "罗萝箩",
    "赏堂党裳掌撑棠常",
    "峻俊骏竣",
    "涛铸",
    "皆楷谐",
    "区匹",
    "过辽疗了",
    "拣练炼",
    "十什计针叶汁",
    "斥诉拆",
    "甬通痛桶诵捅俑涌用拥佣",
    "慢漫幔馒",
    "庆厌",
    "各骆路洛露络",
    "虐虑虚虔",
    "据剧居踞",
    "曾赠憎僧蹭嶒",
    "呙娲祸剐锅涡",
    "建健键",
    "青春清晴睛蜻猜情倩",
    "腮思崽筛",
    "介价阶",
    "住维推堆准",
    "距巨拒炬",
    "寺持等待诗侍特恃峙",
    "朝潮嘲",
    "龙拢笼庞宠茏垄",
    "几讥凯饥肌",
    "吉结洁古桔",
    "士土干于千仕",
    "又权枢杈",
    "捆困团闲",
    "庭挺艇蜓",
    "订盯钉叮",
    "怠殆骀饴怡贻贻",
    "曾增赠僧憎",
    "暑署",
    "旦但担胆",
    "出屈拙倔掘咄",
    "扳仿炮坡",
    "耍要",
    "湛勘斟堪",
    "粟栗",
    "烟埋绳",
    "放旅旋族",
    "织识职",
    "参惨渗",
    "琴瑟",
    "暮蓦墓幕慕摹",
    "高篙稿搞缟",
    "邦帮绑",
    "风枫疯凤讽",
    "忙茫芒氓",
    "我峨娥鹅",
    "句苟",
    "肖消梢销捎悄哨啃稍硝",
    "耐惴",
    "阅悦",
    "亢坑炕抗",
    "熟热",
    "原愿源",
    "尚躺淌趟",
    "眨泛乏之",
    "奏凑挨",
    "尧饶绕浇挠烧",
    "状壮妆",
    "古枯苦姑沽",
    "容蓉熔溶榕",
    "究穷突",
    "叨叼刀刁力",
    "俊骏竣峻",
    "勺匀勾钓均钩沟",
    "官馆管棺",
    "瑰鬼",
    "前煎剪",
    "占沾粘站战黏帖贴玷",
    "正证征歪焉惩症",
    "汗汁",
    "烂栏拦兰",
    "甸句",
    "奄掩淹俺",
    "坚竖",
    "繁敏",
    "帝蹄啼",
    "诞蜒碗婉",
    "力边动劫励历",
    "晤悟",
    "奇寄",
    "且阻组谊宜宣咀",
    "登凳橙蹬澄",
    "爱受援",
    "键健",
    "往住注驻",
    "奉棒捧",
    "昔猎借错蜡惜腊鹊措",
    "辉挥浑",
    "磁滋糍慈",
    "爬抓",
    "脊瘠",
    "诺若",
    "至侄窒倒到致",
    "临监鉴篮蓝滥槛",
    "境镜竞竟",
    "章障彰獐",
    "沸佛拂",
    "澈撤辙",
    "奴努怒恕",
    "湖糊蝴瑚葫",
    "峻俊骏竣浚悛逡唆梭焌",
    "票飘漂瞟",
    "侮悔诲晦",
    "其斯基碁期欺旗",
    "亡芒茫忙盲氓",
    "争筝铮峥挣诤狰净静",
    "右石",
    "具真其",
    "拌绊伴胖",
    "若苦狠狼",
    "巨矩柜拒距",
    "摊滩难瘫",
    "籍藉",
    "蓝篮",
    "异导",
    "吼孔",
    "俘浮",
    "更硬便梗更",
    "丞承",
    "舌刮乱恬括",
    "拔拨托拖",
    "坏怀环还",
    "控腔",
    "旬询殉",
    "因咽胭烟",
    "熬傲遨鏖",
    "开形刑型",
    "及级极汲吸圾",
    "室宝",
    "盒盘盆",
    "骨滑猾",
    "彩采踩睬",
    "啜掇缀",
    "宿缩",
    "嶙粼磷麟鳞",
    "靥魇",
    "刑型荆形",
    "居据剧",
    "急稳隐瘾",
    "登凳橙噔蹬瞪",
    "偶遇寓藕隅",
    "乍作昨诈炸",
    "顽烦顿",
    "胡湖蝴糊",
    "荒谎慌",
    "支枝技歧鼓肢岐",
    "译择泽驿骏绎",
    "帛绵棉锦",
    "央秧殃泱",
    "卒率翠碎",
    "邗邛顼顸",
    "济挤跻脐",
    "段断",
    "旁滂螃榜膀傍谤磅镑",
    "籍藉误娱",
    "仗杖",
    "拼并饼迸",
    "份粉纷分",
    "切彻砌沏",
    "甫捕辅哺铺搏脯膊蒲敷",
    "鬲隔融隅嗝",
    "羽翔翩翘翻翅翱翠",
    "抚芜拴栓",
    "枯姑估",
    "宁狞拧宇亨",
    "主住往注柱驻",
    "易惕踢剔锡赐",
    "挤齐济斋",
    "兹慈磁滋",
    "直值植殖",
    "粗租祖组阻",
    "阑澜斓",
    "样洋鲜祥详",
    "渑绳蝇龟",
    "旦胆但担坦",
    "闻问闷",
    "溅贱残浅",
    "每海诲悔霉晦梅侮",
    "雪寻灵雪扫",
    "堇谨勤",
    "磬罄謦",
    "粮酿浪良",
    "刮乱",
    "辨辩瓣",
    "敬警擎儆",
    "正证症政征",
    "甚堪斟勘湛戡椹",
    "替潜",
    "王斑班狂枉玉主",
    "谣摇遥",
    "冈刚钢纲岗",
    "怕帕",
    "斤折拆析近迈浙哲晰",
    "腊蜡",
    "燥操躁澡噪藻",
    "旺汪",
    "茁拙",
    "厥橛獗",
    "令怜伶邻冷领龄铃岭玲拎",
    "佥险检验脸签捡俭",
    "率摔蟀",
    "拾给",
    "格骆络",
    "娄楼搂数缕偻褛蒌",
    "佳挂桂",
    "旁榜膀傍磅",
    "此柴紫些",
    "方防访妨纺旅仿",
    "虚虑虎",
    "拦栏烂",
    "析浙拆折",
    "岫柚轴舳",
    "疆僵",
    "蜷倦",
    "喘揣端湍瑞",
    "慕幕墓暮",
    "甚堪斟勘湛",
    "胳骼恪络烙咯落格",
    "喝渴蔼",
    "炉庐护",
    "殊铢",
    "铛档挡当裆垱珰",
    "泡饱抱炮跑拘",
    "马驼驮驱驰妈吗骂玛",
    "荒慌谎",
    "风讽枫飘飚飒疯凡",
    "管馆",
    "农浓农",
    "豪毫裳",
    "延诞蜒",
    "撤撒籍霜",
    "羊详样洋鲜群",
    "弟第递梯剃涕",
    "促捉",
    "不丕歪否坏怀环环",
    "宥囿侑",
    "婺骛鹜",
    "翎翔翘翩",
    "鱼鳅鲜鳍鲸鲇",
    "仓苍沧抢枪疮呛炝",
    "烧浇挠",
    "驿泽择译澄",
    "刃忍仞",
    "乖乘剩",
    "辨辫辩瓣",
    "挟狭持待侍诗",
    "氏纸氐抵邸低底",
    "快块",
    "仑纶论沦伦抡轮",
    "估轱沽牯钴诂怙祜佑",
    "摇遥瑶谣",
    "宛碗婉腕蜿",
    "麋鹿麇麂",
    "夸挎垮胯跨",
    "永咏泳脉",
    "匀均钧",
    "牺栖洒晒哂",
    "宵霄",
    "蓝篮监临",
    "油宙笛邮",
    "鸟岛鸣莺鸿鹅鹊鹤",
    "广旷矿",
    "奂焕涣换",
    "良娘狼酿",
    "淄缁辎锱",
    "苟苞",
    "渴竭碣谒",
    "家稼嫁",
    "檫擦",
    "式试拭轼",
    "走趣趋越起趟超陡徒",
    "票漂缥飘剽瓢膘",
    "交狡校郊胶效跤饺绞咬",
    "会侩脍",
    "龚龛詟垄陇",
    "逢缝蓬篷峰锋逢蜂",
    "亢坑炕抗吭",
    "讯迅汛",
    "崔摧催",
    "引张",
    "面腼缅湎苗",
    "贝责负贫贪财账赊帐贺驾货",
    "胡糊蝴湖",
    "雅雄稚",
    "贲喷愤",
    "践贱线钱笺残浅",
    "半伴拌绊叛判",
    "派旅",
    "跨垮挎胯",
    "阵陈",
    "元无远完玩园圆",
    "傲熬赘",
    "桥娇骄矫轿",
    "媚眉",
    "搀馋",
    "虫独浊蛋蚕",
    "喜熹嬉嘻",
    "崇祟综踪",
    "麻磨摩魔靡糜",
    "馀涂途斜叙徐除",
    "涨胀张",
    "真镇",
    "捡脸险",
    "攀拳掌撑",
    "叔淑椒督",
    "茵菌",
    "参惨渗掺",
    "欣颀掀折",
    "诊珍趁",
    "卓桌绰悼掉",
    "摭遮",
    "夭袄沃妘跃妖汪",
    "鬼槐愧魂魄魔",
    "央奂涣唤换焕映英",
    "杏否",
    "府付附附",
    "掐陷馅",
    "躁臊澡操噪燥藻",
    "则测侧铡",
    "谷俗裕豁浴",
    "面腼缅",
    "干杆竿汗",
    "括适话活",
    "郊蛟跤绞",
    "屋层",
    "泛眨乏贬",
    "贯惯贯掼",
    "召诏招昭沼",
    "才财材",
    "揩楷锴谐偕喈",
    "僵疆",
    "票栗",
    "录碌绿禄逮剥",
    "掩淹",
    "模漠摸",
    "赧赦",
    "少沙吵抄炒妙纱",
    "度席",
    "勃脖",
    "哥歌",
    "操燥躁澡",
    "径经泾",
    "付附咐驸府俯腐",
    "劼桔桔诘拮枯",
    "州洲渊",
    "约药",
    "富福幅辐蝠副",
    "皆谐楷",
    "疒瘦病疗疼痒",
    "委萎",
    "验检捡俭",
    "果课棵颗夥界",
    "者诸猪储赌睹堵嘟都煮",
    "谮僭",
    "秀锈绣诱透",
    "立拉垃站粒泣笠",
    "值植直",
    "掣擎",
    "脏桩",
    "瞅啾揪锹楸湫",
    "扬杨汤场肠",
    "吾语悟捂梧",
    "圩盱纡吁",
    "孚俘浮",
    "东冻栋",
    "亦迹峦恋变弈奕蛮",
    "弛驰驰",
    "凉谅晾惊",
    "崖涯",
    "钮羞扭丑",
    "遥摇瑶谣",
    "左在",
    "卌卅州",
    "雨霎雾雷雪霜霆雹",
    "累骡螺摞",
    "盲肓",
    "茶荼荣",
    "卜补扑朴仆",
    "汛迅讯",
    "挠绕饶烧",
    "用拥佣甩",
    "标际示",
    "吕官铝宫",
    "那哪挪娜",
    "缺缸",
    "逝浙",
    "魏巍翼冀",
    "遭糟",
    "踏蹋",
    "韦伟苇纬",
    "具惧俱",
    "秕妣庇毖纰砒毗枇蚍",
    "蛮峦恋奕",
    "疆僵",
    "需懦儒霁",
    "徘排",
    "厮撕",
    "巨拒炬距矩柜",
    "维唯惟难",
    "僖熹",
    "侵寝",
    "监槛",
    "苗描猫瞄",
    "从丛纵众枞",
    "塔搭",
    "弈奕",
    "亥该核咳刻",
    "史驶使",
    "卑脾牌碑",
    "宠庞笼拢",
    "骄轿娇矫",
    "冒昌",
    "是提题堤",
    "岛鸟",
    "提题堤",
    "奇骑寄倚绮椅",
    "嬉禧",
    "韦违韬苇讳伟",
    "姆母拇",
    "班斑",
    "怯劫",
    "讪仙",
    "摊滩难准",
    "莫墓暮幕慕模摸摹漠",
    "满瞒蹒",
    "恰洽怡",
    "尤龙",
    "兰拦栏烂",
    "辰娠唇晨震振辱",
    "弗沸拂佛",
    "废疲",
    "云芸动运耘",
    "浼娩冕晚挽",
    "紫紧",
    "曷渴喝竭褐揭",
    "堂党赏",
    "曹糟嘈遭槽",
    "框筐眶狂",
    "洒晒酒",
    "句苟句",
    "池地驰",
    "幻幼",
    "辛瓣辩辫辨辞辟避宰辣",
    "煎剪",
    "堂瞠膛",
    "次资咨姿",
    "至到倒侄致",
    "扒趴叭",
    "悲辈菲翡",
    "贩波",
    "堵赌睹著",
    "诀决快块缺",
    "灰恢诙炭",
    "客容",
    "鹅饿娥峨",
    "召招照沼",
    "廷挺延涎庭霆艇蜓",
    "勿忽匆葱",
    "区欧沤躯驱岖",
    "哭骂咒器嚣",
    "副福富辐",
    "悔晦诲",
    "凉晾谅京",
    "穴窘穷空窈窕",
    "串患窜",
    "缴激邀",
    "占钻贴粘",
    "乐砾烁",
    "康糠慷",
    "防访纺仿妨",
    "斯撕嘶厮",
    "乔骄桥轿娇侨矫",
    "鞠掬菊",
    "薄搏博膊傅缚簿",
    "买卖读渎椟黩犊续",
    "咸减喊感",
    "包跑炮泡抱袍饱苞刨咆",
    "少妙纱抄沙",
    "苘茼",
    "止址趾耻",
    "毛毡毯毫",
    "玄弦舷眩",
    "谬缪缪戮戳",
    "历厉历励沥",
    "黑墨默嘿黩黯黔",
    "做坐座",
    "绳蝇",
    "半伴拌",
    "吹炊饮欢",
    "汤烫",
    "采彩睬踩釆悉",
    "朱株珠",
    "古枯估故做",
    "敝弊蔽",
    "梨犁",
    "盆岔",
    "编遍扁蝙",
    "虎虚",
    "崇祟",
    "戢缉楫辑",
    "调凋",
    "沾贴帖",
    "票飘漂膘",
    "浪狼娘酿",
    "奂焕涣换焕",
    "喘揣端湍瑞惴",
    "留溜榴榴",
    "炉庐",
    "告浩皓靠诰梏鹄",
    "茸耸",
    "义议仪蚁",
    "尊奠",
    "舟航舰",
    "棍混堤提",
    "培赔陪倍",
    "也弛驰施",
    "周凋调绸稠惆碉雕",
    "赞替潜",
    "厉历",
    "梁粱",
    "渠喋",
    "当挡档",
    "辟避璧譬僻臂壁劈",
    "暴爆曝瀑",
    "屈掘倔",
    "林婪楚梦禁",
    "奇绮畸崎椅倚骑琦",
    "办苏协胁",
    "愿源原",
    "余涂途斜叙徐除",
    "殄畛",
    "长涨胀张",
    "谁唯维推雕难雅崔摧催璀稚雏",
    "思恩",
    "用拥佣",
    "住注往柱驻",
    "论沦轮伦",
    "寸村对才材财",
    "轮论伦沦",
    "殳股役投没般设",
    "苍沧抢枪",
    "珍诊",
    "生性姓星皇",
    "经茎泾径劲胫",
    "尚淌倘躺趟",
    "埋理",
    "誉眷誊举",
    "佰宿缩",
    "彩踩菜睬",
    "成城诚盛",
    "婵蝉箪殚掸惮禅",
    "妥要耍",
    "篙缟槁蒿镐嵩",
    "稍梢哨捎",
    "作昨",
    "咸减喊",
    "努怒弩奴",
    "缝逢峰烽蜂",
    "辟避癖劈壁璧",
    "购构狗够",
    "守宇字",
    "慌谎荒流瀛",
    "忖村讨对",
    "衅畔叛判",
    "寺持等待诗侍特恃峙",
    "卖续读",
    "冠寇",
    "彦颜谚",
    "大太犬夫天禾关共",
    "舌活话括乱刮",
    "只识织职枳帜",
    "斤近折听斩崭断",
    "谓猬",
    "称妳你",
    "居剧据倨锯踞",
    "交郊皎咬胶姣佼绞狡",
    "哀衰蓑猿",
    "帅师",
    "旱昊捍悍",
    "成城诚域",
    "挣净睁",
    "童幢憧撞",
    "摩磨蘑麻",
    "则测侧",
    "箱相湘厢想",
    "蛰蜇",
    "留榴瘤溜遛",
    "浩结洁吉",
    "秋愁",
    "兹慈滋磁",
    "支枝肢",
    "木林材村柄栖柩框沐琳",
    "搏博傅薄礴缚",
    "慢漫",
    "亡忙芒虻",
    "非菲霏排悲匪辈徘",
    "灰诙恢碳炭",
    "京惊凉晾谅掠",
    "探深",
    "箫萧",
    "膺赝",
    "揭竭",
    "之乏芝泛",
    "累螺",
    "祛怯",
    "梯弟涕递挨埃唉",
    "度渡镀席",
    "床桩",
    "刑型",
    "合哈拾答给塔搭恰",
    "暇假霞瑕遐霓",
    "烩荟桧侩刽会",
    "曷渴喝竭褐揭碣遏偈",
    "艰银很恨狠跟",
    "尝偿赏裳",
    "葵擦察祭",
    "甬通痛桶诵捅俑涌",
    "篇骗偏编遍翩",
    "橙澄凳登",
    "灿仙",
    "凑揍",
    "瑞端揣喘",
    "临监鉴篮蓝",
    "楼搂缕",
    "样祥详",
    "包饱泡抱炮袍",
    "稳隐",
    "瓜孤狐抓",
    "多侈移够哆",
    "爪瓜爬抓",
    "瞭缭嘹镣",
    "童撞幢",
    "力历沥枥厉励砺",
    "妲怛袒",
    "澄橙",
    "航杭抗炕",
    "饥肌机讥",
    "涡蜗",
    "肖消梢销捎悄哨稍硝峭俏鞘睄诮帩",
    "铭名茗酩",
    "舀稻蹈",
    "王斑班狂枉琴瑟",
    "劲径茎经颈",
    "彻砌沏切",
    "页顽烦领顺须",
    "俞愉输愈榆喻偷瑜",
    "某谋媒煤",
    "尔你弥猕",
    "妨彷",
    "幼窈坳拗",
    "高稿搞",
    "里童埋理狸暑著",
    "尊遵蹲樽",
    "西茜洒晒酒",
    "扁匾偏翩篇遍骗编蝙",
    "娄屡缕偻搂数喽",
    "糖塘",
    "踝稞窠裸",
    "博搏",
    "袄妖",
    "陨损协胁",
    "市闹柿",
    "麻磨蘑摩靡魔麾",
    "罗萝逻锣箩梦",
    "冷领铃怜",
    "忙芒茫",
    "朗郎踉粮",
    "寿涛祷踌筹铸畴俦",
    "欠次软低吹砍欣欧欢",
    "齐济挤剂跻",
    "酉酒酥酬醉配酿",
    "炼练冻拣",
    "影景",
    "户庐炉房妒驴",
    "惕赐踢",
    "睁挣筝争",
    "鬼瑰愧槐魏魄魂魁",
    "弓引弯湾",
    "仓沧苍伧枪抢",
    "干于",
    "黑默墨黝",
    "浅线钱贱践溅栈饯",
    "还选",
    "通桶痛",
    "找戏",
    "周凋调调绸雕稠",
    "象像橡",
    "建健毽腱键",
    "纤迁",
    "勾构钩沟",
    "今贪念妗吟",
    "复履复",
    "甘钳甜柑",
    "萄淘陶掏",
    "著着者",
    "挂桂洼封卦娃蛙佳哇",
    "竟境镜竞",
    "伐代",
    "考老",
    "魂魄魅魁",
    "熟塾",
    "宗棕综踪淙崇",
    "者都煮暑署躇诸绪赌睹堵",
    "莫漠寞摸模膜",
    "讨付对",
    "资姿咨羡",
    "稿篙嵩蒿",
    "哺捕辅甫",
    "难滩难摊",
    "今令邻领翎冷拎玲铃伶怜",
    "尉慰蔚熨",
    "奋愤",
    "锁销",
    "摇谣遥瑶",
    "辛瓣辩辫辨辞辟避宰辣",
    "寺诗侍峙持待",
    "蠕嚅濡孺懦",
    "捷睫",
    "试拭",
    "米继断眯迷逊昧未迩沬",
    "铺捕哺埔甫辅圃匍蒲",
    "见观现砚觉览视",
    "世屉泄蝶碟",
    "肖消悄稍捎霄哨",
    "吾语捂悟梧",
    "唐糖塘搪",
    "超起",
    "夫扶肤",
    "诟逅",
    "烟咽",
    "脉泳咏永",
    "夸垮跨挎胯污",
    "磋蹉",
    "壁璧辟僻",
    "昆混棍",
    "醇淳谆敦醉",
    "喋牒谍碟堞",
    "容融溶榕",
    "貌藐",
    "敝弊蔽撇蹩瞥",
    "夹狭峡挟侠荚颊",
    "喂偎畏",
    "卒碎醉萃莘瘁粹翠悴",
    "幅副逼福",
    "彼披破坡波",
    "裕欲浴俗",
    "睢雎哺捕脯铺匍匐圃",
    "景影",
    "坐座挫",
    "正证征歪焉惩症",
    "昔惜措错腊蜡",
    "欠炊吹欢饮坎",
    "御卸",
    "暴爆瀑曝",
    "奖桨浆酱犟",
    "取职",
    "飘漂瞟",
    "原盾源愿",
    "遐瑕暇假",
    "比此些芘",
    "裸颗棵课",
    "登凳橙蹬澄",
    "宛碗婉腕蜿惋",
    "溶熔",
    "掏淘陶萄",
    "军浑挥晕晖辉",
    "帮邦绑梆",
    "每海梅悔诲霉",
    "樱婴鹦",
    "齐挤剂",
    "贵溃遗",
    "兑悦说脱",
    "国固",
    "纂篡",
    "斗抖科斟魁料",
    "朋棚鹏鹂",
    "贝见",
    "垂锤睡陲",
    "詹檐瞻赡谵",
    "献现",
    "扑朴补",
    "浦捕哺铺",
    "兆跳眺挑桃逃佻",
    "由迪笛油思邮抽袖柚庙",
    "门闲闷闭闯阔闪",
    "戍戎戊戌",
    "此比",
    "陡徒",
    "寸守付衬村时对过讨",
    "欠炊吹坎",
    "连链莲",
    "直植值殖置",
    "镶壤攘嚷",
    "坑吭抗炕",
    "龌龊龃龉",
    "不坏环",
    "留溜流瘤",
    "兼歉赚嫌谦廉",
    "耳耻职联聘饵茸耸娉俜骋",
    "契楔揳",
    "忻沂坎斫昕",
    "卓桌绰悼掉婥棹淖倬焯",
    "寿涛祷踌筹铸",
    "利俐犁梨",
    "伯柏",
    "乃仍奶及吸极级扔",
    "支枝技歧鼓肢岐山",
    "待诗特",
    "硕项",
    "衰衷",
    "耳耻职联聘饵茸耸",
    "陶掏淘啕",
    "奋备",
    "及乃",
    "豕逐琢啄",
    "伟违纬",
    "贴帖粘站",
    "洗宪冼选",
    "蹈稻滔韬",
    "换焕唤央",
    "沟钩钓钧",
    "覆履屐复",
    "经茎泾径劲佺",
    "内肉",
    "女妥要耍",
    "赛塞寒",
    "操躁澡",
    "板饭返扳贩",
    "杳沓",
    "敖熬傲遨赘",
    "己记纪妃已巳",
    "廷廷挺庭霆艇蜓",
    "示标祭票",
    "区沤躯驱岖欧殴讴呕怄抠枢伛妪鸥",
    "斩渐崭暂",
    "金全",
    "链键钱铜针",
    "果棵颗课稞",
    "崩蹦绷鹏",
    "氏纸低底抵",
    "罐灌罐",
    "很银限艰根跟狠",
    "章障彰獐",
    "揪鳅",
    "敝蔽憋鳖弊",
    "旦担坦",
    "遗匮馈遣",
    "买卖",
    "央秧映殃",
    "囊壤攘镶嚷馕瓤",
    "卜补扑仆朴赴",
    "捷睫",
    "堂棠裳赏",
    "即既颇须榜傍磅膀",
    "复履覆",
    "谨勤",
    "幻幼",
    "瓜爪弧",
    "非菲霏排悲匪辈徘徊",
    "焦蕉礁瞧憔樵",
    "浑辉挥晖",
    "里童埋理狸暑着",
    "般没投役",
    "秀绣系锈透",
    "锦棉绵帛",
    "洁结桔",
    "帝啼谛缔蒂蹄",
    "漆膝",
    "具俱惧飓",
    "合哈拾答给塔搭恰",
    "青清晴情晴静睛精猜靓靛倩靓",
    "亭停婷",
    "厉励沥历",
    "皿盐监盆盒孟猛盂",
    "乙乞艺忆迄屹亿",
    "曼慢漫蔓馒幔",
    "于宇吁迂",
    "勺趵钓约的灼",
    "公讼松",
    "榆愉喻",
    "援暖缓",
    "詹檐瞻",
    "仓沧白伧枪抢",
    "垂陲睡锤棰捶",
    "刚钢岗纲",
    "传转砖",
    "哲暂晢",
    "奋备思佃亩",
    "白怕帕伯拍泊柏陌珀",
    "付付附腐符俯",
    "肚吐杜",
    "委萎魏姿",
    "兵滨缤摈傧宾",
    "危跪桅诡脆",
    "我峨娥",
    "并开",
    "羽翔翩翘翻翅翱",
    "身射躲",
    "盐盆盒孟猛盂",
    "麻床",
    "兽曾",
    "货袋贷代",
    "分粉芬份纷芳",
    "加驾架",
    "痛疼病",
    "竟镜境",
    "格恪铭",
    "必密蜜秘",
    "测侧则",
    "概慨溉既",
    "本笨体木",
    "甩用",
    "艮狠恨狼娘恳垦",
    "极级吸",
    "圭蛙娃洼桂挂佳祥涯崖封畦",
    "杨汤场扬",
    "犄犄掎犄畸崎绮漪旖倚",
    "部陪倍",
    "固涸",
    "容溶榕",
    "侮海悔梅",
    "需儒孺濡",
    "粘沾",
    "真慎填",
    "柝坼祗诋邸柢砥抵抵泜胝",
    "麻磨摩魔靡",
    "亘恒宣喧楦渲",
    "撕嘶期琪其",
    "车军浑挥晖辉",
    "梧悟晤语",
    "皮破波坡彼被玻披疲跛皱",
    "阡迁歼奸",
    "唐塘搪糖",
    "刍皱煞邹",
    "脾卑碑啤",
    "主注往柱驻住",
    "朝潮嘲瀚",
    "绞跤",
    "吹炊",
    "雀省",
    "章彰樟璋蟑",
    "从丛纵众",
    "火灭灾伙炎淡谈",
    "白怕拍伯泊柏佰",
    "祥详翔样",
    "导异",
    "富副幅逼福",
    "嬴蠃瀛羸赢",
    "永泳咏",
    "式拭试",
    "申中神伸坤绅",
    "狐孤抓",
    "培赔陪蓓",
    "肄肆",
    "颁颔颌颀硕颐",
    "抬胎苔台合",
    "惩征",
    "调雕凋碉",
    "丰峰锋烽蜂逢缝蓬",
    "查渣碴",
    "蒙檬朦曚",
    "摘滴",
    "徂狙沮咀龃趄诅俎租",
    "哥歌鬲隔融嗝",
    "上止址让企扯肯",
    "盎蛊盂盅",
    "努怒",
    "警擎",
    "末未味咪昧抹",
    "品晶",
    "吴昊误娱",
    "亘恒宣喧楦渲桓垣晅萱暄喧瑄烜楦仾",
    "八扒趴穴",
    "皮披波菠坡彼",
    "尤忧优",
    "绊拌",
    "显星湿垦",
    "皮破波坡彼被玻披疲跛皱",
    "倦蜷眷卷巷券誉誊",
    "京凉谅晾景惊掠",
    "员陨损",
    "考烤拷铐",
    "既溉慨概",
    "悼掉",
    "息熄",
    "沁泌",
    "干秆杆轩",
    "碟蝶",
    "捧棒",
    "嫌谦歉廉",
    "牙呀芽雅讶",
    "千纤迁仟",
    "朝潮嘲澈撤辙",
    "柜拒炬矩",
    "君群裙郡",
    "展辰辗碾",
    "兆挑桃窕逃",
    "诈榨",
    "势执挚",
    "劝动功",
    "非韭徘辈悲斐裴靠扉霏菲匪蜚排",
    "丁订钉叮盯打",
    "申审伸呻",
    "谋媒煤某",
    "仰昂迎抑",
    "冈刚钢岗纲",
    "相箱霜湘",
    "约钓",
    "岷泯眠氏民",
    "创枪",
    "劳涝捞",
    "货贷",
    "寿夀",
"瓯甄",
"苺莓",
"爰爱",
"香晋秀",
"玉五",
"鲜鱻",
"目国图",
"享享",
"度逗",
"泉香",
"阁门",
"偌诺",
"香番",
"蜜壹",
"朗郎",
"百北佰白",
"六大",
"童宣",
"卸缷",
"洛落",
"运远",
"良来",
"魔鹿",
"堪勘",
"芊仟",
"三山",
"祥翔",
"铭合含",
"澎澍",
"杜社",
"晨曼晟",
"高亮",
"宴晏",
"祥洋",
"扳搬",
"忙芒",
"穗德",
"蘭兰竺",
"手平",
"筏垡",
"苑筑",
"美卖",
"俊骁佬",
"妍研",
"染柒",
"耘云",
"林秋",
"跃腾",
"醫一",
"烙饹络",
"菜蒸莱",
"窗富",
"听昕",
"家星",
"新断",
"锦银",
"棒帮",
"鱼画鲁渔",
"草茉",
"峪崆裕",
"逹达",
"木十",
"廲麗",
"鹿麗",
"木林",
"岐歧",
"果菓",
"裘姿安",
"桌卓",
"缙晋",
"倪伣",
"绍邰邵",
"子千予孑",
"Y丫",
"陆六",
"桉按",
"慧惠",
"衣侬依",
"膳墡",
"炫炖",
"化花",
"升昇",
"尼尼泥妮昵坭铌伲",
"娅桠亚哑垭亜亞覀",
"音昔善普",
"素秦泰",
"掂惦",
"微徽",
"坊邡",
"芦卢",
"熊热能",
"食良",
"篱离璃漓蓠",
"谜迷",
"祈折",
"爔燨",
"窖窰窑",
"侯候",
"耀燿",
"蝎羯",
"沪泸",
"涧间",
"荫阴",
"尙尚",
"厦夏",
"扇煽",
"骊雨丽",
"茄笳",
"垈垡",
"揖辑",
"如和",
"死成",
"瑧臻瑧",
"哒跶",
"芮苪",
"壵垚",
"享亨亭",
"柘拓",
"希肴",
"郝赫",
"麟麒",
"可河柯珂苛荀呵",
"灸炙",
"臧藏",
"π兀",
"栅棚删",
"定淀",
"钎纤",
"熙煦",
"嘎噶",
"毫亳",
"苶茶",
"塵麈",
"薜薛",
"佘余",
"春舂",
"涑洓",
"忐忑",
"盼盻",
"西覀",
"嗔瞋",
"磐槃",
"袓祖",
"彧或",
"两俩",
"降隆",
"饨顿",
"狮蛳",
"菅萱",
"凭赁",
"蜴蝎",
"笛亩",
"蟹螯",
"劳券劵",
"戚威",
"吉古",
"擘擎挚",
"顾颐",
"看香",
"勹勺",
"吴呈",
"翟霍",
"廉康",
"种秤",
"畜蓄",
"浦辅",
"宠宏",
"钝饨",
"汩汨",
"汆氽",
"壸壶",
"洗冼",
"银锒",
"祟崇",
"雎睢",
"亓元",
"胃胄",
"毒毐",
"拔拨",
"钹䥽",
"丐丏",
"迴迥",
"荫萌",
"炴炔",
"丹舟",
"雷富",
"根粮",
"康庚",
"音喜",
"茂芪",
"骏驳",
"培格",
"榛椿",
"明朋",
"州川",
"汯法",
"优伏",
"怀杯",
"牤牝",
"乒乓兵",
"锌梓",
"寰宸",
"幸辛",
"阳陌",
"袆祎",
"戊戌戎戍",
"魑魅魍魉",
"袄祅",
"嫪谬",
"冇有",
"冃月",
"锐税",
"彬杉",
"兄只",
"厂广",
"艺芝",
"私俬弘",
"行仃仟",
"米来",
"妹姝",
"栢柏",
"袛祗祇衹",
"瀛灜",
"衍绗",
"珏钰",
"浜滨",
"玥钥",
"茜茵",
"硒晒",
"窝窉",
"芏茔",
"炑林",
"剌刺",
"僳傈",
"牦蚝耗",
"屋喔",
"仑仓",
"萁箕",
"熳漫",
"摖擦",
"姜娄",
"瑗瑷",
"乌鸟",
"简筒",
"甪角",
"炖饨",
"醋酷",
"祙袜",
"妤好",
"日曰",
"頣颐",
"廋瘦",
"创刨",
"乎呼",
"董堇",
"熏薰"
]